@@ -26,7 +26,7 @@
 	because it stands for 1/8, a sixteenth note is 16, etc.
 	These are all pretty straight forward, but how do you define a sixteenth 
 	triplet? Well, sixteenth triplets are made by taking an eight note 
-	and deviding it in 3 equal parts. 1/8 * 1/3 = 1/24; so 24 is the number 
+	and deviding it in 3 equal parts. 1/8 \* 1/3 = 1/24; so 24 is the number 
 	we want. How about a dotted eight note? A dotted eight note has the length
 	of an eight note plus half an eight note. 1/8 + 1/16 = 3/16 = 1 / 16 / 3.
 	So 16/3 is the number we are looking for. 
